@@ -298,12 +298,6 @@ class ClientApplication(Frame):
         self._prepare_debug_game()
 
     def _prepare_debug_game(self):
-        import os
-        import pkg_resources
-        print '__name__', __name__
-        print pkg_resources.resource_filename(__name__, 'scriptcraft/graphic/base.png')
-        print os.getcwd()
-
         # load game and add player
         stream = open(datafile_path('maps/default.map'), 'r')
         game_map = pickle.load(stream)
